@@ -1,9 +1,9 @@
 package Benchmark::Perl::Formance;
-# git description: v0.53-13-gd912390
+# git description: v0.54-2-g52509be
 
 our $AUTHORITY = 'cpan:SCHWIGON';
 # ABSTRACT: Perl 5 performance benchmarking framework
-$Benchmark::Perl::Formance::VERSION = '0.54';
+$Benchmark::Perl::Formance::VERSION = '0.55';
 use 5.008;
 
 use warnings;
@@ -430,8 +430,12 @@ sub _get_perl_config_notaintsupport {
 
         my $config_args = $Config{config_args};
         my $notaintsupport = 0; # standard
-        if ($config_args =~ /-DNO_TAINT_SUPPORT\b/ and not _taint_available()) {
-          $notaintsupport = 1;
+        if ($config_args =~ /(SILENT_)?NO_TAINT_SUPPORT\b/) {
+            if ($config_args =~ /SILENT_NO_TAINT_SUPPORT\b/) {
+                $notaintsupport = 1; # no further check possible
+            } else {
+                $notaintsupport = 1 if not _taint_available();
+            }
         }
         return $notaintsupport;
 }
